=====================================
wvflib — OBJ Mesh Files Reader/Writer
=====================================

.. image:: https://travis-ci.org/resurtm/wvflib.svg?branch=master
    :target: https://travis-ci.org/resurtm/wvflib

.. image:: https://badge.fury.io/py/wvflib.svg
    :target: https://badge.fury.io/py/wvflib
